@@ -15,6 +15,7 @@ from testflows._core.cli.arg.common import epilog
 from testflows._core.cli.arg.common import HelpFormatter
 from testflows._core.cli.arg.handlers.handler import Handler as HandlerBase
 from testflows._core.cli.arg.handlers.show.test.handler import Handler as test_handler
+from testflows._core.cli.arg.handlers.show.tests.handler import Handler as tests_handler
 
 class Handler(HandlerBase):
     @classmethod
@@ -27,3 +28,4 @@ class Handler(HandlerBase):
             description=None, help=None)
         show_commands.required = True
         test_handler.add_command(show_commands)
+        tests_handler.add_command(show_commands)
