@@ -59,13 +59,17 @@ def format_input(msg, keyword):
     out += color("\u270b " + msg.message, "yellow", attrs=["bold"]) + cursor_up() + "\n"
     return out
 
-def format_description(msg, indent):
-    first, rest = (msg.description.description.rstrip() + "\n").split("\n", 1)
+def format_multiline(text, indent):
+    first, rest = (text.rstrip() + "\n").split("\n", 1)
     first = first.strip()
     if first:
         first += "\n"
-    desc = f"{first}{textwrap.dedent(rest.rstrip())}".rstrip()
-    desc = textwrap.indent(desc, indent + "  ")
+    out = f"{first}{textwrap.dedent(rest.rstrip())}".rstrip()
+    out = textwrap.indent(out, indent + "  ")
+    return out
+
+def format_description(msg, indent):
+    desc = format_multiline(msg.description.description, indent)
     desc = color(desc, "white", attrs=["dim"])
     return desc + "\n"
 
@@ -92,7 +96,7 @@ def format_tags(msg, indent):
 def format_examples(msg, indent):
     examples = ExamplesTable(*msg.examples)
     out = [f"{indent}{' ' * 2}{color_secondary_keyword('Examples')}"]
-    out.append(color(textwrap.indent(f"{examples}", prefix=f"{indent}{' ' * 6}"), "white", attrs=["dim"]))
+    out.append(color(textwrap.indent(f"{examples}", prefix=f"{indent}{' ' * 4}"), "white", attrs=["dim"]))
     return "\n".join(out) + "\n"
 
 def format_arguments(msg, indent):
@@ -141,7 +145,10 @@ def format_test(msg, keyword):
     if msg.p_type == TestType.Module:
         keyword += "Module"
     elif msg.p_type == TestType.Suite:
-        keyword += "Suite"
+        if msg.p_subtype == TestSubType.Feature:
+            keyword += "Feature"
+        else:
+            keyword += "Suite"
     elif msg.p_type == TestType.Iteration:
         keyword += "Iteration"
     elif msg.p_type == TestType.Step:
@@ -162,9 +169,7 @@ def format_test(msg, keyword):
         else:
             keyword += "Step"
     else:
-        if msg.p_subtype == TestSubType.Feature:
-            keyword += "Feature"
-        elif msg.p_subtype == TestSubType.Scenario:
+        if msg.p_subtype == TestSubType.Scenario:
             keyword += "Scenario"
         elif msg.p_subtype == TestSubType.Background:
             keyword += "Background"
@@ -201,11 +206,13 @@ def format_result(msg, prefix, result):
         return
     _result = color_result(prefix, result)
     _test = color_other(basename(msg.test))
+    _indent = indent * (msg.p_id.count('/') - 1)
 
     return (color_other(f"{strftimedelta(msg.p_time):>20}") +
-        f"{'':3}{indent * (msg.p_id.count('/') - 1)}{_result} "
-        f"{_test}{color_other(', ' + msg.test)}{color_other((', ' + msg.message) if msg.message else '')}"
-        f"{color_other((', ' + msg.reason) if msg.reason else '')}\n")
+        f"{'':3}{_indent}{_result} "
+        f"{_test}{color_other(', ' + msg.test)}"
+        f"{(color_other(', ') + color(format_multiline(msg.message, _indent + ' ' * 26).lstrip(), 'yellow', attrs=['bold'])) if msg.message else ''}"
+        f"{(color_other(', ') + color(msg.reason, 'blue', attrs=['bold'])) if msg.reason else ''}\n")
 
 def format_other(msg, keyword):
     if Flags(msg.p_flags) & SKIP and settings.show_skipped is False:
